@@ -1,17 +1,21 @@
 #' Obtaining dates using other dates (or month or year) as reference
-#' 
-#' Imagine you have one date and want the first or last day of this date's month.
+#'
+#' Imagine you have one date and want the first or last day of this date's
+#' month.
 #' For example, you have the date 2018-02-01 and want the last day of its month.
 #' You have to check whether or not its year is a leap year, and this sounds a
 #' tough task.
 #' \code{getdate} helps with returning specific dates according to a reference
 #' than can be another date, a month or an year.
-#' 
-#' @param expr a character string specifying the date to be returned (see Details)
-#' @param ref a reference which represents a month or year, where the date has to be found.
+#'
+#' @param expr a character string specifying the date to be returned
+#'             (see Details)
+#' @param ref a reference which represents a month or year, where the
+#'            date has to be found.
 #' @param cal the calendar's name
-#' 
-#' \code{expr} represents the day has to be returned, here it follows a few examples:
+#'
+#' \code{expr} represents the day has to be returned, here it follows a few
+#' examples:
 #' \itemize{
 #'   \item \code{"second day"}
 #'   \item \code{"10th bizday"}
@@ -19,7 +23,7 @@
 #'   \item \code{"last bizday"}
 #'   \item \code{"first fri"}
 #' }
-#' 
+#'
 #' \code{expr} is a character string with two terms: \code{"<position> <day>"}
 #' \itemize{
 #'   \item positions: \code{first} or \code{1st},
@@ -29,14 +33,15 @@
 #'   \item days: \code{day}, \code{bizday}, or weekdays (\code{sun}, \code{mon},
 #'   \code{tue}, \code{wed}, \code{thu}, \code{fri}, \code{sat})
 #' }
-#' 
+#'
 #' \code{getdate} returns dates according to a reference that can be a month or
-#' an year. This reference can be passed as a character vector representing months
-#' or years, or as a numeric vector representing years. The ISO format must be 
-#' used to represent years or months with character vectors.
-#' 
+#' an year. This reference can be passed as a character vector representing
+#' months or years, or as a numeric vector representing years.
+#' The ISO format must be used to represent years or months with character
+#' vectors.
+#'
 #' @examples
-#' getdate("10th wed", 2018, "actual")
+#' getdate("10th wed", 2018, "Brazil/ANBIMA")
 #' getdate("last bizday", 2010:2018, "Brazil/ANBIMA")
 #' dts <- seq(as.Date("2018-01-01"), as.Date("2018-12-01"), "month")
 #' getdate("first bizday", format(dts, "%Y-%m"), "Brazil/ANBIMA")
@@ -45,53 +50,60 @@ getdate <- function(expr, ref, cal = bizdays.options$get("default.calendar")) {
   cal <- check_calendar(cal)
   ref <- ref(ref)
   tok <- strsplit(expr, "\\s+")[[1]]
-  if (length(tok) != 2)
+  if (length(tok) != 2) {
     stop("Invalid expr", expr)
+  }
   n <- getnth_(tok[1])
   if (tok[2] == "day") {
-    date_res <- lapply(seq_len(NROW(ref$year_month)),
-                       function(x) getnthday_(n, ref, cal, x))
+    date_res <- lapply(
+      seq_len(NROW(ref$year_month)),
+      function(x) getnthday_(n, ref, cal, x)
+    )
     as.Date(unlist(date_res), origin = as.Date("1970-01-01"))
   } else if (tok[2] == "bizday") {
-    date_res <- lapply(seq_len(NROW(ref$year_month)),
-                       function(x) getnthday_(n, ref, cal, x, TRUE))
+    date_res <- lapply(
+      seq_len(NROW(ref$year_month)),
+      function(x) getnthday_(n, ref, cal, x, TRUE)
+    )
     as.Date(unlist(date_res), origin = as.Date("1970-01-01"))
   } else if (tok[2] %in% WEEKDAYS) {
     wday <- which(tok[2] == WEEKDAYS)
-    date_res <- lapply(seq_len(NROW(ref$year_month)),
-                       function(x) getnthweekday_(n, ref, cal, wday, x))
+    date_res <- lapply(
+      seq_len(NROW(ref$year_month)),
+      function(x) getnthweekday_(n, ref, cal, wday, x)
+    )
     as.Date(unlist(date_res), origin = as.Date("1970-01-01"))
-  } else
+  } else {
     stop("Invalid expr", expr)
+  }
 }
 
 #' Creates date references to be used in \code{getdate}
-#' 
+#'
 #' Date references are specifically months or years to be used in
 #' \code{getdate}.
 #' Months and years can be specified directly or can be base on a given date.
 #' \code{getdate} returns a date that is in the reference passed.
-#' 
+#'
 #' @param x a \code{Date} vector, a character vector (specifying dates, months
 #' or years) or a numeric vector (specifying years)
 #' @param ym a character string with the values \code{month} or \code{year} (see
 #' Details)
 #' @param ... additional arguments
-#' 
+#'
 #' If a date (\code{character} or \code{Date}) is passed to \code{ref} it has to
 #' specified whether the reference is to the month or the year of the given
-#' date. This is set in the argument \code{ym} that accepts \code{month} (default) or
-#' \code{year}.
-#' 
+#' date. This is set in the argument \code{ym} that accepts \code{month}
+#' (default) or \code{year}.
+#'
 #' @examples
 #' ref(as.Date("2018-01-01"), "month") # refers to 2018-01
-#' ref("2018-01-01", "month")          # refers to 2018-01
-#' ref("2018-01-01", "year")           # refers to 2018
-#' 
+#' ref("2018-01-01", "month") # refers to 2018-01
+#' ref("2018-01-01", "year") # refers to 2018
+#'
 #' ref(c("2018-01", "2018-02")) # refers to 2018-01 and 2018-02
 #' ref("2018") # refers to 2018
 #' ref(2010:2018) # refers to all years from 2010 to 2018
-#' 
 #' @noRd
 ref <- function(x, ...) UseMethod("ref")
 
@@ -119,8 +131,10 @@ ref.character <- function(x, ...) {
     mx <- do.call(rbind, mx)
     list(
       by_month = TRUE,
-      year_month = cbind(year = as.integer(mx[, 2]),
-                         month = as.integer(mx[, 3]))
+      year_month = cbind(
+        year = as.integer(mx[, 2]),
+        month = as.integer(mx[, 3])
+      )
     )
   } else if (all(grepl("^(\\d{4})$", x))) {
     mx <- regmatches(x, regexec("^(\\d{4})$", x))
@@ -131,8 +145,9 @@ ref.character <- function(x, ...) {
     )
   } else if (all(grepl("^\\d{4}-\\d{2}-\\d{2}$", x))) {
     do.call(ref.Date, append(list(...), list(x = as.Date(x))))
-  } else
+  } else {
     stop("Invalid character ref ", x)
+  }
   structure(that, class = "ref")
 }
 
@@ -151,14 +166,14 @@ YEAR <- function(x) as.integer(format(x, "%Y"))
 nth2int <- function(x) {
   rx <- regexec("^(\\d+)th$", x)
   mx <- regmatches(x, rx)[[1]]
-  if (length(mx) == 0)
+  if (length(mx) == 0) {
     stop("Invalid position nth", x)
+  }
   as.integer(mx[[2]])
 }
 
 getnth_ <- function(x) {
-  switch(
-    x,
+  switch(x,
     first = 1,
     second = 2,
     third = 3,
@@ -200,4 +215,4 @@ getnthweekday_ <- function(pos, ref, cal, wday, ref_pos = 1) {
   unname(res)
 }
 
-WEEKDAYS <- c("thu", "fri", "sat", "sun", "mon", "tue", "wed")
+WEEKDAYS <- c("thu", "fri", "sat", "sun", "mon", "tue", "wed")
\ No newline at end of file
